pub struct RecoveryManager { /* private fields */ }Expand description
Distributed recovery manager.
Discovers the latest valid checkpoint, restores operator state, and seeks source connectors to the checkpoint offsets.
Implementations
Sourceimpl RecoveryManager
impl RecoveryManager
Sourcepub fn new(checkpointer: Arc<dyn Checkpointer>, config: RecoveryConfig) -> Self
pub fn new(checkpointer: Arc<dyn Checkpointer>, config: RecoveryConfig) -> Self
Create a new recovery manager.
Sourcepub async fn recover(
&self,
restorables: &mut [&mut dyn Restorable],
seekables: &mut [&mut dyn Seekable],
) -> Result<RecoveryResult, RecoveryError>
pub async fn recover( &self, restorables: &mut [&mut dyn Restorable], seekables: &mut [&mut dyn Seekable], ) -> Result<RecoveryResult, RecoveryError>
Run the full recovery sequence.
Arguments
restorables— mutable references to operator state objectsseekables— mutable references to source connectors
Errors
Returns RecoveryError if recovery fails (no checkpoint,
corrupt data, operator mismatch, etc.).
Sourcepub async fn recover_typed(
&self,
restorables: &mut [&mut dyn Restorable],
typed_seekables: &mut [&mut dyn TypedSeekable],
) -> Result<RecoveryResult, RecoveryError>
pub async fn recover_typed( &self, restorables: &mut [&mut dyn Restorable], typed_seekables: &mut [&mut dyn TypedSeekable], ) -> Result<RecoveryResult, RecoveryError>
Run the full recovery sequence with typed source seeking (F-E2E-001).
This is the same as recover() but uses
TypedSeekable for type-safe source position restoration.
Errors
Returns RecoveryError if recovery fails.