Seekable

Trait Seekable 

pub trait Seekable: Send + Sync {
    // Required methods
    fn seek(
        &mut self,
        offsets: &HashMap<String, String>,
    ) -> Result<(), RecoveryError>;
    fn source_id(&self) -> &str;
}
Trait for source connectors that can seek to a checkpoint offset.

Required Methods

fn seek( &mut self, offsets: &HashMap<String, String>, ) -> Result<(), RecoveryError>

Seek the source to a previously checkpointed offset.

Errors

Returns RecoveryError::SeekFailed if the source cannot seek to the given offsets (e.g., expired Kafka offsets).

fn source_id(&self) -> &str

Source identifier (must match the key in the manifest).

Implementors