pub struct RecoveryManager { /* private fields */ }Expand description
Recovery manager for restoring state from checkpoints and WAL.
Implementations
Sourceimpl RecoveryManager
impl RecoveryManager
Sourcepub fn new(config: RecoveryConfig) -> Self
pub fn new(config: RecoveryConfig) -> Self
Creates a new recovery manager.
Sourcepub fn recover(&self) -> Result<RecoveredState, IncrementalCheckpointError>
pub fn recover(&self) -> Result<RecoveredState, IncrementalCheckpointError>
Performs full recovery from checkpoint + WAL.
This is the main recovery entry point that:
- Finds the latest valid checkpoint
- Loads checkpoint state
- Replays WAL entries after the checkpoint
Errors
Returns an error if recovery fails.
Sourcepub fn recover_simple(
checkpoint_dir: &Path,
wal_path: &Path,
) -> Result<RecoveredState, IncrementalCheckpointError>
pub fn recover_simple( checkpoint_dir: &Path, wal_path: &Path, ) -> Result<RecoveredState, IncrementalCheckpointError>
Sourcepub fn recover_with_changes(
checkpoint_dir: &Path,
wal_path: &Path,
) -> Result<RecoveredState, IncrementalCheckpointError>
pub fn recover_with_changes( checkpoint_dir: &Path, wal_path: &Path, ) -> Result<RecoveredState, IncrementalCheckpointError>
Recovers and returns state changes for application to state store.
Errors
Returns an error if recovery fails.